Class: AmznSpApi::FinancesApiModel::TrialShipmentEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/finances_api_model/models/trial_shipment_event.rb

Overview

An event related to a trial shipment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TrialShipmentEvent

Initializes the object

Raises:

  • (ArgumentError)


55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 55

def initialize(attributes = {})
  raise ArgumentError, 'The input argument (attributes) must be a hash in `AmznSpApi::FinancesApiModel::TrialShipmentEvent` initialize method' unless attributes.is_a?(Hash)

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    raise ArgumentError, "`#{k}` is not a valid attribute in `AmznSpApi::FinancesApiModel::TrialShipmentEvent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect unless self.class.attribute_map.key?(k.to_sym)

    h[k.to_sym] = v
  end

  self.amazon_order_id = attributes[:amazon_order_id] if attributes.key?(:amazon_order_id)

  self.financial_event_group_id = attributes[:financial_event_group_id] if attributes.key?(:financial_event_group_id)

  self.posted_date = attributes[:posted_date] if attributes.key?(:posted_date)

  self.sku = attributes[:sku] if attributes.key?(:sku)

  return unless attributes.key?(:fee_list)

  self.fee_list = attributes[:fee_list]
end

Instance Attribute Details

#amazon_order_idObject

An Amazon-defined identifier for an order.



16
17
18
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 16

def amazon_order_id
  @amazon_order_id
end

#fee_listObject

Returns the value of attribute fee_list.



21
22
23
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 21

def fee_list
  @fee_list
end

#financial_event_group_idObject

The identifier of the financial event group.



19
20
21
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 19

def financial_event_group_id
  @financial_event_group_id
end

#posted_dateObject

Returns the value of attribute posted_date.



21
22
23
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 21

def posted_date
  @posted_date
end

#skuObject

The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.



24
25
26
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 24

def sku
  @sku
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 27

def self.attribute_map
  {
    'amazon_order_id': :AmazonOrderId,
    'financial_event_group_id': :FinancialEventGroupId,
    'posted_date': :PostedDate,
    'sku': :SKU,
    'fee_list': :FeeList
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



118
119
120
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 118

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



49
50
51
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 49

def self.openapi_nullable
  Set.new([])
end

.openapi_typesObject

Attribute type mapping.



38
39
40
41
42
43
44
45
46
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 38

def self.openapi_types
  {
    'amazon_order_id': :Object,
    'financial_event_group_id': :Object,
    'posted_date': :Object,
    'sku': :Object,
    'fee_list': :Object
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



92
93
94
95
96
97
98
99
100
101
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 92

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    amazon_order_id == other.amazon_order_id &&
    financial_event_group_id == other.financial_event_group_id &&
    posted_date == other.posted_date &&
    sku == other.sku &&
    fee_list == other.fee_list
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 147

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    AmznSpApi::FinancesApiModel.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 216

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 125

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }) if attributes[self.class.attribute_map[key]].is_a?(Array)
    elsif !attributes[self.class.attribute_map[key]].nil?
      send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      send("#{key}=", nil)
    end
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


105
106
107
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 105

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.



111
112
113
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 111

def hash
  [amazon_order_id, financial_event_group_id, posted_date, sku, fee_list].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



80
81
82
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 80

def list_invalid_properties
  []
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



192
193
194
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 192

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 198

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



186
187
188
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 186

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



86
87
88
# File 'lib/finances_api_model/models/trial_shipment_event.rb', line 86

def valid?
  true
end