Class: AmznSpApi::UploadsApiModel::UploadsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/uploads_api_model/api/uploads_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UploadsApi



14
15
16
# File 'lib/uploads_api_model/api/uploads_api.rb', line 14

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



12
13
14
# File 'lib/uploads_api_model/api/uploads_api.rb', line 12

def api_client
  @api_client
end

Instance Method Details

#create_upload_destination_for_resource(marketplace_ids, content_md5, resource, opts = {}) ⇒ CreateUploadDestinationResponse

Creates an upload destination, returning the information required to upload a file to the destination and to programmatically access the file. Usage Plan: | Rate (requests per second) | Burst | | ---- | ---- | | 10 | 10 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.

Options Hash (opts):

  • :content_type (String)

    The content type of the file to be uploaded.



25
26
27
28
# File 'lib/uploads_api_model/api/uploads_api.rb', line 25

def create_upload_destination_for_resource(marketplace_ids, content_md5, resource, opts = {})
  data, _status_code, _headers = create_upload_destination_for_resource_with_http_info(marketplace_ids, content_md5, resource, opts)
  data
end

#create_upload_destination_for_resource_with_http_info(marketplace_ids, content_md5, resource, opts = {}) ⇒ Array<(CreateUploadDestinationResponse, Integer, Hash)>

Creates an upload destination, returning the information required to upload a file to the destination and to programmatically access the file. Usage Plan: | Rate (requests per second) | Burst | | ---- | ---- | | 10 | 10 | The `x-amzn-RateLimit-Limit` response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.

Options Hash (opts):

  • :content_type (String)

    The content type of the file to be uploaded.

Raises:

  • (ArgumentError)


37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/uploads_api_model/api/uploads_api.rb', line 37

def create_upload_destination_for_resource_with_http_info(marketplace_ids, content_md5, resource, opts = {})
  @api_client.config.logger.debug 'Calling API: UploadsApi.create_upload_destination_for_resource ...' if @api_client.config.debugging
  # verify the required parameter 'marketplace_ids' is set
  raise ArgumentError, "Missing the required parameter 'marketplace_ids' when calling UploadsApi.create_upload_destination_for_resource" if @api_client.config.client_side_validation && marketplace_ids.nil?
  # verify the required parameter 'content_md5' is set
  raise ArgumentError, "Missing the required parameter 'content_md5' when calling UploadsApi.create_upload_destination_for_resource" if @api_client.config.client_side_validation && content_md5.nil?
  # verify the required parameter 'resource' is set
  raise ArgumentError, "Missing the required parameter 'resource' when calling UploadsApi.create_upload_destination_for_resource" if @api_client.config.client_side_validation && resource.nil?

  # resource path
  local_var_path = '/uploads/2020-11-01/uploadDestinations/{resource}'.sub('{' + 'resource' + '}', resource.to_s)

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:marketplaceIds] = @api_client.build_collection_param(marketplace_ids, :csv)
  query_params[:contentMD5] = content_md5
  query_params[:contentType] = opts[:content_type] unless opts[:content_type].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body]

  return_type = opts[:return_type] || 'CreateUploadDestinationResponse'

  auth_names = opts[:auth_names] || []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
                                                    header_params: header_params,
                                                    query_params: query_params,
                                                    form_params: form_params,
                                                    body: post_body,
                                                    auth_names: auth_names,
                                                    return_type: return_type)

  @api_client.config.logger.debug "API called: UploadsApi#create_upload_destination_for_resource\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" if @api_client.config.debugging
  [data, status_code, headers]
end