Method: AmznSpApi::AplusContentApiModel::StandardComparisonTableModule#build_from_hash
- Defined in:
- lib/aplus_content_api_model/models/standard_comparison_table_module.rb
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/aplus_content_api_model/models/standard_comparison_table_module.rb', line 104 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }) if attributes[self.class.attribute_map[key]].is_a?(Array) elsif !attributes[self.class.attribute_map[key]].nil? send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) elsif attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) send("#{key}=", nil) end end self end |