Module: AmznSpApi::ProductPricingApiModel
- Defined in:
- lib/product_pricing_api_model/version.rb,
lib/product_pricing_api_model.rb,
lib/product_pricing_api_model/api_error.rb,
lib/product_pricing_api_model/api_client.rb,
lib/product_pricing_api_model/models/sku.rb,
lib/product_pricing_api_model/models/asin.rb,
lib/product_pricing_api_model/models/error.rb,
lib/product_pricing_api_model/models/price.rb,
lib/product_pricing_api_model/configuration.rb,
lib/product_pricing_api_model/models/errors.rb,
lib/product_pricing_api_model/models/points.rb,
lib/product_pricing_api_model/models/condition.rb,
lib/product_pricing_api_model/models/http_body.rb,
lib/product_pricing_api_model/models/error_list.rb,
lib/product_pricing_api_model/models/money_type.rb,
lib/product_pricing_api_model/models/http_method.rb,
lib/product_pricing_api_model/models/http_headers.rb,
lib/product_pricing_api_model/models/batch_request.rb,
lib/product_pricing_api_model/models/batch_response.rb,
lib/product_pricing_api_model/models/featured_offer.rb,
lib/product_pricing_api_model/models/marketplace_id.rb,
lib/product_pricing_api_model/api/product_pricing_api.rb,
lib/product_pricing_api_model/models/fulfillment_type.rb,
lib/product_pricing_api_model/models/http_status_line.rb,
lib/product_pricing_api_model/models/offer_identifier.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price_result.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price_request.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price_response.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price_result_list.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price_request_list.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price_response_body.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price_response_list.rb,
lib/product_pricing_api_model/models/featured_offer_expected_price_request_params.rb,
lib/product_pricing_api_model/models/get_featured_offer_expected_price_batch_request.rb,
lib/product_pricing_api_model/models/get_featured_offer_expected_price_batch_response.rb
Overview
#Selling Partner API for Pricing
The Selling Partner API for Pricing helps you programmatically retrieve product pricing and offer pricing information for Amazon Marketplace products. For more information, see the Product Pricing v2022-05-01 Use Case Guide.
OpenAPI spec version: 2022-05-01
Generated by: https://github.com/swagger-api/swagger-codegen.git Swagger Codegen version: 3.0.36
Defined Under Namespace
Classes: ApiClient, ApiError, Asin, BatchRequest, BatchResponse, Condition, Configuration, Error, ErrorList, Errors, FeaturedOffer, FeaturedOfferExpectedPrice, FeaturedOfferExpectedPriceRequest, FeaturedOfferExpectedPriceRequestList, FeaturedOfferExpectedPriceRequestParams, FeaturedOfferExpectedPriceResponse, FeaturedOfferExpectedPriceResponseBody, FeaturedOfferExpectedPriceResponseList, FeaturedOfferExpectedPriceResult, FeaturedOfferExpectedPriceResultList, FulfillmentType, GetFeaturedOfferExpectedPriceBatchRequest, GetFeaturedOfferExpectedPriceBatchResponse, HttpBody, HttpHeaders, HttpMethod, HttpStatusLine, MarketplaceId, MoneyType, OfferIdentifier, Points, Price, ProductPricingApi, Sku
Constant Summary collapse
- VERSION =
'1.0.0'
Class Method Summary collapse
-
.configure ⇒ Object
Customize default settings for the SDK using block.
Class Method Details
.configure ⇒ Object
Customize default settings for the SDK using block. AmznSpApi::ProductPricingApiModel.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.
59 60 61 62 63 64 65 |
# File 'lib/product_pricing_api_model.rb', line 59 def configure if block_given? yield(Configuration.default) else Configuration.default end end |